# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FrecencyUserSettings.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x46recencyUserSettings.proto\x12\x34\x64iscord_protos.discord_users.v1.FrecencyUserSettings\"\xd0\x16\n\x14\x46recencyUserSettings\x12j\n\x08versions\x18\x01 \x01(\x0b\x32S.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.VersionsH\x00\x88\x01\x01\x12s\n\rfavorite_gifs\x18\x02 \x01(\x0b\x32W.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.FavoriteGIFsH\x01\x88\x01\x01\x12{\n\x11\x66\x61vorite_stickers\x18\x03 \x01(\x0b\x32[.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.FavoriteStickersH\x02\x88\x01\x01\x12y\n\x10sticker_frecency\x18\x04 \x01(\x0b\x32Z.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.StickerFrecencyH\x03\x88\x01\x01\x12w\n\x0f\x66\x61vorite_emojis\x18\x05 \x01(\x0b\x32Y.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.FavoriteEmojisH\x04\x88\x01\x01\x12u\n\x0e\x65moji_frecency\x18\x06 \x01(\x0b\x32X.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.EmojiFrecencyH\x05\x88\x01\x01\x12\x90\x01\n\x1c\x61pplication_command_frecency\x18\x07 \x01(\x0b\x32\x65.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.ApplicationCommandFrecencyH\x06\x88\x01\x01\x12\x8c\x01\n\x1a\x66\x61vorite_soundboard_sounds\x18\x08 \x01(\x0b\x32\x63.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.FavoriteSoundboardSoundsH\x07\x88\x01\x01\x1aP\n\x08Versions\x12\x16\n\x0e\x63lient_version\x18\x01 \x01(\r\x12\x16\n\x0eserver_version\x18\x02 \x01(\r\x12\x14\n\x0c\x64\x61ta_version\x18\x03 \x01(\r\x1a\xac\x01\n\x0b\x46\x61voriteGIF\x12\x62\n\x06\x66ormat\x18\x01 \x01(\x0e\x32R.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.GIFType\x12\x0b\n\x03src\x18\x02 \x01(\t\x12\r\n\x05width\x18\x03 \x01(\r\x12\x0e\n\x06height\x18\x04 \x01(\r\x12\r\n\x05order\x18\x05 \x01(\r\x1a\x9b\x02\n\x0c\x46\x61voriteGIFs\x12o\n\x04gifs\x18\x01 \x03(\x0b\x32\x61.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.FavoriteGIFs.GifsEntry\x12\x14\n\x0chide_tooltip\x18\x02 \x01(\x08\x1a\x83\x01\n\tGifsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x65\n\x05value\x18\x02 \x01(\x0b\x32V.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.FavoriteGIF:\x02\x38\x01\x1a\'\n\x10\x46\x61voriteStickers\x12\x13\n\x0bsticker_ids\x18\x01 \x03(\x06\x1aX\n\x0c\x46recencyItem\x12\x12\n\ntotal_uses\x18\x01 \x01(\r\x12\x13\n\x0brecent_uses\x18\x02 \x03(\x04\x12\x10\n\x08\x66recency\x18\x03 \x01(\x05\x12\r\n\x05score\x18\x04 \x01(\x05\x1a\x98\x02\n\x0fStickerFrecency\x12z\n\x08stickers\x18\x01 \x03(\x0b\x32h.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.StickerFrecency.StickersEntry\x1a\x88\x01\n\rStickersEntry\x12\x0b\n\x03key\x18\x01 \x01(\x06\x12\x66\n\x05value\x18\x02 \x01(\x0b\x32W.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.FrecencyItem:\x02\x38\x01\x1a \n\x0e\x46\x61voriteEmojis\x12\x0e\n\x06\x65mojis\x18\x01 \x03(\t\x1a\x8e\x02\n\rEmojiFrecency\x12t\n\x06\x65mojis\x18\x01 \x03(\x0b\x32\x64.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.EmojiFrecency.EmojisEntry\x1a\x86\x01\n\x0b\x45mojisEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x66\n\x05value\x18\x02 \x01(\x0b\x32W.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.FrecencyItem:\x02\x38\x01\x1a\xd1\x02\n\x1a\x41pplicationCommandFrecency\x12\x9c\x01\n\x14\x61pplication_commands\x18\x01 \x03(\x0b\x32~.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.ApplicationCommandFrecency.ApplicationCommandsEntry\x1a\x93\x01\n\x18\x41pplicationCommandsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x66\n\x05value\x18\x02 \x01(\x0b\x32W.discord_protos.discord_users.v1.FrecencyUserSettings.FrecencyUserSettings.FrecencyItem:\x02\x38\x01\x1a-\n\x18\x46\x61voriteSoundboardSounds\x12\x11\n\tsound_ids\x18\x01 \x03(\x06\")\n\x07GIFType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\t\n\x05VIDEO\x10\x02\x42\x0b\n\t_versionsB\x10\n\x0e_favorite_gifsB\x14\n\x12_favorite_stickersB\x13\n\x11_sticker_frecencyB\x12\n\x10_favorite_emojisB\x11\n\x0f_emoji_frecencyB\x1f\n\x1d_application_command_frecencyB\x1d\n\x1b_favorite_soundboard_soundsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'FrecencyUserSettings_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FRECENCYUSERSETTINGS_FAVORITEGIFS_GIFSENTRY._options = None
  _FRECENCYUSERSETTINGS_FAVORITEGIFS_GIFSENTRY._serialized_options = b'8\001'
  _FRECENCYUSERSETTINGS_STICKERFRECENCY_STICKERSENTRY._options = None
  _FRECENCYUSERSETTINGS_STICKERFRECENCY_STICKERSENTRY._serialized_options = b'8\001'
  _FRECENCYUSERSETTINGS_EMOJIFRECENCY_EMOJISENTRY._options = None
  _FRECENCYUSERSETTINGS_EMOJIFRECENCY_EMOJISENTRY._serialized_options = b'8\001'
  _FRECENCYUSERSETTINGS_APPLICATIONCOMMANDFRECENCY_APPLICATIONCOMMANDSENTRY._options = None
  _FRECENCYUSERSETTINGS_APPLICATIONCOMMANDFRECENCY_APPLICATIONCOMMANDSENTRY._serialized_options = b'8\001'
  _FRECENCYUSERSETTINGS._serialized_start=85
  _FRECENCYUSERSETTINGS._serialized_end=2981
  _FRECENCYUSERSETTINGS_VERSIONS._serialized_start=1112
  _FRECENCYUSERSETTINGS_VERSIONS._serialized_end=1192
  _FRECENCYUSERSETTINGS_FAVORITEGIF._serialized_start=1195
  _FRECENCYUSERSETTINGS_FAVORITEGIF._serialized_end=1367
  _FRECENCYUSERSETTINGS_FAVORITEGIFS._serialized_start=1370
  _FRECENCYUSERSETTINGS_FAVORITEGIFS._serialized_end=1653
  _FRECENCYUSERSETTINGS_FAVORITEGIFS_GIFSENTRY._serialized_start=1522
  _FRECENCYUSERSETTINGS_FAVORITEGIFS_GIFSENTRY._serialized_end=1653
  _FRECENCYUSERSETTINGS_FAVORITESTICKERS._serialized_start=1655
  _FRECENCYUSERSETTINGS_FAVORITESTICKERS._serialized_end=1694
  _FRECENCYUSERSETTINGS_FRECENCYITEM._serialized_start=1696
  _FRECENCYUSERSETTINGS_FRECENCYITEM._serialized_end=1784
  _FRECENCYUSERSETTINGS_STICKERFRECENCY._serialized_start=1787
  _FRECENCYUSERSETTINGS_STICKERFRECENCY._serialized_end=2067
  _FRECENCYUSERSETTINGS_STICKERFRECENCY_STICKERSENTRY._serialized_start=1931
  _FRECENCYUSERSETTINGS_STICKERFRECENCY_STICKERSENTRY._serialized_end=2067
  _FRECENCYUSERSETTINGS_FAVORITEEMOJIS._serialized_start=2069
  _FRECENCYUSERSETTINGS_FAVORITEEMOJIS._serialized_end=2101
  _FRECENCYUSERSETTINGS_EMOJIFRECENCY._serialized_start=2104
  _FRECENCYUSERSETTINGS_EMOJIFRECENCY._serialized_end=2374
  _FRECENCYUSERSETTINGS_EMOJIFRECENCY_EMOJISENTRY._serialized_start=2240
  _FRECENCYUSERSETTINGS_EMOJIFRECENCY_EMOJISENTRY._serialized_end=2374
  _FRECENCYUSERSETTINGS_APPLICATIONCOMMANDFRECENCY._serialized_start=2377
  _FRECENCYUSERSETTINGS_APPLICATIONCOMMANDFRECENCY._serialized_end=2714
  _FRECENCYUSERSETTINGS_APPLICATIONCOMMANDFRECENCY_APPLICATIONCOMMANDSENTRY._serialized_start=2567
  _FRECENCYUSERSETTINGS_APPLICATIONCOMMANDFRECENCY_APPLICATIONCOMMANDSENTRY._serialized_end=2714
  _FRECENCYUSERSETTINGS_FAVORITESOUNDBOARDSOUNDS._serialized_start=2716
  _FRECENCYUSERSETTINGS_FAVORITESOUNDBOARDSOUNDS._serialized_end=2761
  _FRECENCYUSERSETTINGS_GIFTYPE._serialized_start=2763
  _FRECENCYUSERSETTINGS_GIFTYPE._serialized_end=2804
# @@protoc_insertion_point(module_scope)



from enum import Enum as _Enum
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from google.protobuf.message import Message as _Message

    FrecencyUserSettings = PreloadedUserSettings = _Message
else:
    from .FrecencyUserSettings_pb2 import FrecencyUserSettings
    from .PreloadedUserSettings_pb2 import PreloadedUserSettings


class UserSettingsType(_Enum):
    preloaded_user_settings = 1
    frecency_user_settings = 2
    test_settings = 3


UserSettingsImpl = {
    UserSettingsType.preloaded_user_settings: PreloadedUserSettings,
    UserSettingsType.frecency_user_settings: FrecencyUserSettings,
    UserSettingsType.test_settings: None,
}


__version__ = '0.0.2'



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PreloadedUserSettings.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bPreloadedUserSettings.proto\x12\x35\x64iscord_protos.discord_users.v1.PreloadedUserSettings\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd5[\n\x15PreloadedUserSettings\x12l\n\x08versions\x18\x01 \x01(\x0b\x32U.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.VersionsH\x00\x88\x01\x01\x12n\n\x05inbox\x18\x02 \x01(\x0b\x32Z.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.InboxSettingsH\x01\x88\x01\x01\x12r\n\x06guilds\x18\x03 \x01(\x0b\x32].discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.AllGuildSettingsH\x02\x88\x01\x01\x12{\n\x0cuser_content\x18\x04 \x01(\x0b\x32`.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.UserContentSettingsH\x03\x88\x01\x01\x12\x80\x01\n\x0fvoice_and_video\x18\x05 \x01(\x0b\x32\x62.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.VoiceAndVideoSettingsH\x04\x88\x01\x01\x12\x80\x01\n\x0ftext_and_images\x18\x06 \x01(\x0b\x32\x62.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.TextAndImagesSettingsH\x05\x88\x01\x01\x12}\n\rnotifications\x18\x07 \x01(\x0b\x32\x61.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.NotificationSettingsH\x06\x88\x01\x01\x12r\n\x07privacy\x18\x08 \x01(\x0b\x32\\.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.PrivacySettingsH\x07\x88\x01\x01\x12n\n\x05\x64\x65\x62ug\x18\t \x01(\x0b\x32Z.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.DebugSettingsH\x08\x88\x01\x01\x12{\n\x0cgame_library\x18\n \x01(\x0b\x32`.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.GameLibrarySettingsH\t\x88\x01\x01\x12p\n\x06status\x18\x0b \x01(\x0b\x32[.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.StatusSettingsH\n\x88\x01\x01\x12|\n\x0clocalization\x18\x0c \x01(\x0b\x32\x61.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.LocalizationSettingsH\x0b\x88\x01\x01\x12x\n\nappearance\x18\r \x01(\x0b\x32_.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.AppearanceSettingsH\x0c\x88\x01\x01\x12u\n\rguild_folders\x18\x0e \x01(\x0b\x32Y.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.GuildFoldersH\r\x88\x01\x01\x12n\n\tfavorites\x18\x0f \x01(\x0b\x32V.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.FavoritesH\x0e\x88\x01\x01\x12\x7f\n\x16\x61udio_context_settings\x18\x10 \x01(\x0b\x32Z.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.AudioSettingsH\x0f\x88\x01\x01\x12z\n\x0b\x63ommunities\x18\x11 \x01(\x0b\x32`.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.CommunitiesSettingsH\x10\x88\x01\x01\x1aP\n\x08Versions\x12\x16\n\x0e\x63lient_version\x18\x01 \x01(\r\x12\x16\n\x0eserver_version\x18\x02 \x01(\r\x12\x14\n\x0c\x64\x61ta_version\x18\x03 \x01(\r\x1a\x94\x01\n\rInboxSettings\x12j\n\x0b\x63urrent_tab\x18\x01 \x01(\x0e\x32U.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.InboxTab\x12\x17\n\x0fviewed_tutorial\x18\x02 \x01(\x08\x1a-\n\x0f\x43hannelSettings\x12\x1a\n\x12\x63ollapsed_in_inbox\x18\x01 \x01(\x08\x1a\xd9\x03\n\rGuildSettings\x12z\n\x08\x63hannels\x18\x01 \x03(\x0b\x32h.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.GuildSettings.ChannelsEntry\x12\x14\n\x0chub_progress\x18\x02 \x01(\r\x12!\n\x19guild_onboarding_progress\x18\x03 \x01(\r\x12\x43\n\x1aguild_recents_dismissed_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x1f\n\x17\x64ismissed_guild_content\x18\x05 \x01(\x0c\x1a\x8d\x01\n\rChannelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x06\x12k\n\x05value\x18\x02 \x01(\x0b\x32\\.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.ChannelSettings:\x02\x38\x01\x42\x1d\n\x1b_guild_recents_dismissed_at\x1a\x99\x02\n\x10\x41llGuildSettings\x12y\n\x06guilds\x18\x01 \x03(\x0b\x32i.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.AllGuildSettings.GuildsEntry\x1a\x89\x01\n\x0bGuildsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x06\x12i\n\x05value\x18\x02 \x01(\x0b\x32Z.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.GuildSettings:\x02\x38\x01\x1a\xad\x02\n\x13UserContentSettings\x12\x1a\n\x12\x64ismissed_contents\x18\x01 \x01(\x0c\x12W\n,last_dismissed_outbound_promotion_start_date\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x88\x01\x01\x12J\n!premium_tier_0_modal_dismissed_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x42/\n-_last_dismissed_outbound_promotion_start_dateB$\n\"_premium_tier_0_modal_dismissed_at\x1a-\n\x19VideoFilterBackgroundBlur\x12\x10\n\x08use_blur\x18\x01 \x01(\x08\x1a\x32\n\x10VideoFilterAsset\x12\n\n\x02id\x18\x01 \x01(\x06\x12\x12\n\nasset_hash\x18\x02 \x01(\t\x1a$\n\x12SoundboardSettings\x12\x0e\n\x06volume\x18\x01 \x01(\x02\x1a\xad\x06\n\x15VoiceAndVideoSettings\x12t\n\x04\x62lur\x18\x01 \x01(\x0b\x32\x66.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.VideoFilterBackgroundBlur\x12\x15\n\rpreset_option\x18\x02 \x01(\r\x12s\n\x0c\x63ustom_asset\x18\x03 \x01(\x0b\x32].discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.VideoFilterAsset\x12=\n\x14\x61lways_preview_video\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x88\x01\x01\x12\x36\n\x0b\x61\x66k_timeout\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueH\x01\x88\x01\x01\x12\x45\n\x1cstream_notifications_enabled\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x02\x88\x01\x01\x12I\n native_phone_integration_enabled\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x03\x88\x01\x01\x12\x81\x01\n\x13soundboard_settings\x18\t \x01(\x0b\x32_.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.SoundboardSettingsH\x04\x88\x01\x01\x42\x17\n\x15_always_preview_videoB\x0e\n\x0c_afk_timeoutB\x1f\n\x1d_stream_notifications_enabledB#\n!_native_phone_integration_enabledB\x16\n\x14_soundboard_settings\x1a\xfb\x0e\n\x15TextAndImagesSettings\x12>\n\x13\x64iversity_surrogate\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x88\x01\x01\x12<\n\x13use_rich_chat_input\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x01\x88\x01\x01\x12;\n\x12use_thread_sidebar\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x02\x88\x01\x01\x12:\n\x0frender_spoilers\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x03\x88\x01\x01\x12\'\n\x1f\x65moji_picker_collapsed_sections\x18\x05 \x03(\t\x12)\n!sticker_picker_collapsed_sections\x18\x06 \x03(\t\x12@\n\x17view_image_descriptions\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x04\x88\x01\x01\x12\x41\n\x18show_command_suggestions\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x05\x88\x01\x01\x12@\n\x17inline_attachment_media\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x06\x88\x01\x01\x12;\n\x12inline_embed_media\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x07\x88\x01\x01\x12\x36\n\rgif_auto_play\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x08\x88\x01\x01\x12\x36\n\rrender_embeds\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\t\x88\x01\x01\x12\x39\n\x10render_reactions\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\n\x88\x01\x01\x12\x36\n\ranimate_emoji\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x0b\x88\x01\x01\x12;\n\x10\x61nimate_stickers\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueH\x0c\x88\x01\x01\x12;\n\x12\x65nable_tts_command\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\r\x88\x01\x01\x12@\n\x17message_display_compact\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x0e\x88\x01\x01\x12\x42\n\x17\x65xplicit_content_filter\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueH\x0f\x88\x01\x01\x12\x39\n\x10view_nsfw_guilds\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x10\x88\x01\x01\x12:\n\x11\x63onvert_emoticons\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x11\x88\x01\x01\x12G\n\x1e\x65xpression_suggestions_enabled\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x12\x88\x01\x01\x12;\n\x12view_nsfw_commands\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x13\x88\x01\x01\x12>\n\x15use_legacy_chat_input\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x14\x88\x01\x01\x42\x16\n\x14_diversity_surrogateB\x16\n\x14_use_rich_chat_inputB\x15\n\x13_use_thread_sidebarB\x12\n\x10_render_spoilersB\x1a\n\x18_view_image_descriptionsB\x1b\n\x19_show_command_suggestionsB\x1a\n\x18_inline_attachment_mediaB\x15\n\x13_inline_embed_mediaB\x10\n\x0e_gif_auto_playB\x10\n\x0e_render_embedsB\x13\n\x11_render_reactionsB\x10\n\x0e_animate_emojiB\x13\n\x11_animate_stickersB\x15\n\x13_enable_tts_commandB\x1a\n\x18_message_display_compactB\x1a\n\x18_explicit_content_filterB\x13\n\x11_view_nsfw_guildsB\x14\n\x12_convert_emoticonsB!\n\x1f_expression_suggestions_enabledB\x15\n\x13_view_nsfw_commandsB\x18\n\x16_use_legacy_chat_input\x1a\x87\x02\n\x14NotificationSettings\x12\x42\n\x19show_in_app_notifications\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x88\x01\x01\x12\x42\n\x19notify_friends_on_go_live\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x01\x88\x01\x01\x12+\n#notification_center_acked_before_id\x18\x03 \x01(\x06\x42\x1c\n\x1a_show_in_app_notificationsB\x1c\n\x1a_notify_friends_on_go_live\x1a\xf6\n\n\x0fPrivacySettings\x12M\n$allow_activity_party_privacy_friends\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x88\x01\x01\x12S\n*allow_activity_party_privacy_voice_channel\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x01\x88\x01\x01\x12\x1c\n\x14restricted_guild_ids\x18\x03 \x03(\x06\x12!\n\x19\x64\x65\x66\x61ult_guilds_restricted\x18\x04 \x01(\x08\x12%\n\x1d\x61llow_accessibility_detection\x18\x07 \x01(\x08\x12\x41\n\x18\x64\x65tect_platform_accounts\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x02\x88\x01\x01\x12\x35\n\x0cpasswordless\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x03\x88\x01\x01\x12=\n\x14\x63ontact_sync_enabled\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x04\x88\x01\x01\x12>\n\x13\x66riend_source_flags\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueH\x05\x88\x01\x01\x12\x41\n\x16\x66riend_discovery_flags\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueH\x06\x88\x01\x01\x12%\n\x1d\x61\x63tivity_restricted_guild_ids\x18\r \x03(\x06\x12\x9e\x01\n\"default_guilds_activity_restricted\x18\x0e \x01(\x0e\x32r.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.GuildActivityStatusRestrictionDefault\x12-\n%activity_joining_restricted_guild_ids\x18\x0f \x03(\x06\x12,\n$message_request_restricted_guild_ids\x18\x10 \x03(\x06\x12K\n\"default_message_request_restricted\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x07\x88\x01\x01\x12\x38\n\x0f\x64rops_opted_out\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x08\x88\x01\x01\x12\x43\n\x1anon_spam_retraining_opt_in\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\t\x88\x01\x01\x42\'\n%_allow_activity_party_privacy_friendsB-\n+_allow_activity_party_privacy_voice_channelB\x1b\n\x19_detect_platform_accountsB\x0f\n\r_passwordlessB\x17\n\x15_contact_sync_enabledB\x16\n\x14_friend_source_flagsB\x19\n\x17_friend_discovery_flagsB%\n#_default_message_request_restrictedB\x12\n\x10_drops_opted_outB\x1d\n\x1b_non_spam_retraining_opt_in\x1au\n\rDebugSettings\x12\x44\n\x1brtc_panel_show_voice_states\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x88\x01\x01\x42\x1e\n\x1c_rtc_panel_show_voice_states\x1a\xad\x02\n\x13GameLibrarySettings\x12\x41\n\x18install_shortcut_desktop\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x88\x01\x01\x12\x44\n\x1binstall_shortcut_start_menu\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x01\x88\x01\x01\x12:\n\x11\x64isable_games_tab\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x02\x88\x01\x01\x42\x1b\n\x19_install_shortcut_desktopB\x1e\n\x1c_install_shortcut_start_menuB\x14\n\x12_disable_games_tab\x1aY\n\x0c\x43ustomStatus\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x65moji_id\x18\x02 \x01(\x06\x12\x12\n\nemoji_name\x18\x03 \x01(\t\x12\x15\n\rexpires_at_ms\x18\x04 \x01(\x06\x1a\xa9\x02\n\x0eStatusSettings\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x88\x01\x01\x12u\n\rcustom_status\x18\x02 \x01(\x0b\x32Y.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.CustomStatusH\x01\x88\x01\x01\x12:\n\x11show_current_game\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x02\x88\x01\x01\x42\t\n\x07_statusB\x10\n\x0e_custom_statusB\x14\n\x12_show_current_game\x1a\xa3\x01\n\x14LocalizationSettings\x12\x31\n\x06locale\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x88\x01\x01\x12\x39\n\x0ftimezone_offset\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueH\x01\x88\x01\x01\x42\t\n\x07_localeB\x12\n\x10_timezone_offset\x1a\xb0\x02\n\x13\x43lientThemeSettings\x12\x38\n\rprimary_color\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueH\x00\x88\x01\x01\x12H\n\x1d\x62\x61\x63kground_gradient_preset_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueH\x01\x88\x01\x01\x12\x43\n\x19\x62\x61\x63kground_gradient_angle\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueH\x02\x88\x01\x01\x42\x10\n\x0e_primary_colorB \n\x1e_background_gradient_preset_idB\x1c\n\x1a_background_gradient_angle\x1a\xd2\x02\n\x12\x41ppearanceSettings\x12\x61\n\x05theme\x18\x01 \x01(\x0e\x32R.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.Theme\x12\x16\n\x0e\x64\x65veloper_mode\x18\x02 \x01(\x08\x12\x84\x01\n\x15\x63lient_theme_settings\x18\x03 \x01(\x0b\x32`.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.ClientThemeSettingsH\x00\x88\x01\x01\x12 \n\x18mobile_redesign_disabled\x18\x04 \x01(\x08\x42\x18\n\x16_client_theme_settings\x1a\xcb\x01\n\x0bGuildFolder\x12\x11\n\tguild_ids\x18\x01 \x03(\x06\x12,\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x00\x88\x01\x01\x12/\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x01\x88\x01\x01\x12\x30\n\x05\x63olor\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueH\x02\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_nameB\x08\n\x06_color\x1a\x92\x01\n\x0cGuildFolders\x12i\n\x07\x66olders\x18\x01 \x03(\x0b\x32X.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.GuildFolder\x12\x17\n\x0fguild_positions\x18\x02 \x03(\x06\x1a\xb8\x01\n\x0f\x46\x61voriteChannel\x12\x10\n\x08nickname\x18\x01 \x01(\t\x12n\n\x04type\x18\x02 \x01(\x0e\x32`.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.FavoriteChannelType\x12\x10\n\x08position\x18\x03 \x01(\r\x12\x11\n\tparent_id\x18\x04 \x01(\x06\x1a\xbc\x02\n\tFavorites\x12\x87\x01\n\x11\x66\x61vorite_channels\x18\x01 \x03(\x0b\x32l.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.Favorites.FavoriteChannelsEntry\x12\r\n\x05muted\x18\x02 \x01(\x08\x1a\x95\x01\n\x15\x46\x61voriteChannelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x06\x12k\n\x05value\x18\x02 \x01(\x0b\x32\\.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.FavoriteChannel:\x02\x38\x01\x1aI\n\x13\x41udioContextSetting\x12\r\n\x05muted\x18\x01 \x01(\x08\x12\x0e\n\x06volume\x18\x02 \x01(\x02\x12\x13\n\x0bmodified_at\x18\x03 \x01(\x06\x1a\x9d\x04\n\rAudioSettings\x12r\n\x04user\x18\x01 \x03(\x0b\x32\x64.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.AudioSettings.UserEntry\x12v\n\x06stream\x18\x02 \x03(\x0b\x32\x66.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.AudioSettings.StreamEntry\x1a\x8d\x01\n\tUserEntry\x12\x0b\n\x03key\x18\x01 \x01(\x06\x12o\n\x05value\x18\x02 \x01(\x0b\x32`.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.AudioContextSetting:\x02\x38\x01\x1a\x8f\x01\n\x0bStreamEntry\x12\x0b\n\x03key\x18\x01 \x01(\x06\x12o\n\x05value\x18\x02 \x01(\x0b\x32`.discord_protos.discord_users.v1.PreloadedUserSettings.PreloadedUserSettings.AudioContextSetting:\x02\x38\x01\x1ao\n\x13\x43ommunitiesSettings\x12>\n\x15\x64isable_home_auto_nav\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x88\x01\x01\x42\x18\n\x16_disable_home_auto_nav\"N\n\x08InboxTab\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08MENTIONS\x10\x01\x12\x0b\n\x07UNREADS\x10\x02\x12\t\n\x05TODOS\x10\x03\x12\x0b\n\x07\x46OR_YOU\x10\x04\"I\n%GuildActivityStatusRestrictionDefault\x12\x07\n\x03OFF\x10\x00\x12\x17\n\x13ON_FOR_LARGE_GUILDS\x10\x01\"\'\n\x05Theme\x12\t\n\x05UNSET\x10\x00\x12\x08\n\x04\x44\x41RK\x10\x01\x12\t\n\x05LIGHT\x10\x02\"\\\n\x13\x46\x61voriteChannelType\x12\x1f\n\x1bUNSET_FAVORITE_CHANNEL_TYPE\x10\x00\x12\x16\n\x12REFERENCE_ORIGINAL\x10\x01\x12\x0c\n\x08\x43\x41TEGORY\x10\x02\x42\x0b\n\t_versionsB\x08\n\x06_inboxB\t\n\x07_guildsB\x0f\n\r_user_contentB\x12\n\x10_voice_and_videoB\x12\n\x10_text_and_imagesB\x10\n\x0e_notificationsB\n\n\x08_privacyB\x08\n\x06_debugB\x0f\n\r_game_libraryB\t\n\x07_statusB\x0f\n\r_localizationB\r\n\x0b_appearanceB\x10\n\x0e_guild_foldersB\x0c\n\n_favoritesB\x19\n\x17_audio_context_settingsB\x0e\n\x0c_communitiesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PreloadedUserSettings_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRELOADEDUSERSETTINGS_GUILDSETTINGS_CHANNELSENTRY._options = None
  _PRELOADEDUSERSETTINGS_GUILDSETTINGS_CHANNELSENTRY._serialized_options = b'8\001'
  _PRELOADEDUSERSETTINGS_ALLGUILDSETTINGS_GUILDSENTRY._options = None
  _PRELOADEDUSERSETTINGS_ALLGUILDSETTINGS_GUILDSENTRY._serialized_options = b'8\001'
  _PRELOADEDUSERSETTINGS_FAVORITES_FAVORITECHANNELSENTRY._options = None
  _PRELOADEDUSERSETTINGS_FAVORITES_FAVORITECHANNELSENTRY._serialized_options = b'8\001'
  _PRELOADEDUSERSETTINGS_AUDIOSETTINGS_USERENTRY._options = None
  _PRELOADEDUSERSETTINGS_AUDIOSETTINGS_USERENTRY._serialized_options = b'8\001'
  _PRELOADEDUSERSETTINGS_AUDIOSETTINGS_STREAMENTRY._options = None
  _PRELOADEDUSERSETTINGS_AUDIOSETTINGS_STREAMENTRY._serialized_options = b'8\001'
  _PRELOADEDUSERSETTINGS._serialized_start=152
  _PRELOADEDUSERSETTINGS._serialized_end=11885
  _PRELOADEDUSERSETTINGS_VERSIONS._serialized_start=2228
  _PRELOADEDUSERSETTINGS_VERSIONS._serialized_end=2308
  _PRELOADEDUSERSETTINGS_INBOXSETTINGS._serialized_start=2311
  _PRELOADEDUSERSETTINGS_INBOXSETTINGS._serialized_end=2459
  _PRELOADEDUSERSETTINGS_CHANNELSETTINGS._serialized_start=2461
  _PRELOADEDUSERSETTINGS_CHANNELSETTINGS._serialized_end=2506
  _PRELOADEDUSERSETTINGS_GUILDSETTINGS._serialized_start=2509
  _PRELOADEDUSERSETTINGS_GUILDSETTINGS._serialized_end=2982
  _PRELOADEDUSERSETTINGS_GUILDSETTINGS_CHANNELSENTRY._serialized_start=2810
  _PRELOADEDUSERSETTINGS_GUILDSETTINGS_CHANNELSENTRY._serialized_end=2951
  _PRELOADEDUSERSETTINGS_ALLGUILDSETTINGS._serialized_start=2985
  _PRELOADEDUSERSETTINGS_ALLGUILDSETTINGS._serialized_end=3266
  _PRELOADEDUSERSETTINGS_ALLGUILDSETTINGS_GUILDSENTRY._serialized_start=3129
  _PRELOADEDUSERSETTINGS_ALLGUILDSETTINGS_GUILDSENTRY._serialized_end=3266
  _PRELOADEDUSERSETTINGS_USERCONTENTSETTINGS._serialized_start=3269
  _PRELOADEDUSERSETTINGS_USERCONTENTSETTINGS._serialized_end=3570
  _PRELOADEDUSERSETTINGS_VIDEOFILTERBACKGROUNDBLUR._serialized_start=3572
  _PRELOADEDUSERSETTINGS_VIDEOFILTERBACKGROUNDBLUR._serialized_end=3617
  _PRELOADEDUSERSETTINGS_VIDEOFILTERASSET._serialized_start=3619
  _PRELOADEDUSERSETTINGS_VIDEOFILTERASSET._serialized_end=3669
  _PRELOADEDUSERSETTINGS_SOUNDBOARDSETTINGS._serialized_start=3671
  _PRELOADEDUSERSETTINGS_SOUNDBOARDSETTINGS._serialized_end=3707
  _PRELOADEDUSERSETTINGS_VOICEANDVIDEOSETTINGS._serialized_start=3710
  _PRELOADEDUSERSETTINGS_VOICEANDVIDEOSETTINGS._serialized_end=4523
  _PRELOADEDUSERSETTINGS_TEXTANDIMAGESSETTINGS._serialized_start=4526
  _PRELOADEDUSERSETTINGS_TEXTANDIMAGESSETTINGS._serialized_end=6441
  _PRELOADEDUSERSETTINGS_NOTIFICATIONSETTINGS._serialized_start=6444
  _PRELOADEDUSERSETTINGS_NOTIFICATIONSETTINGS._serialized_end=6707
  _PRELOADEDUSERSETTINGS_PRIVACYSETTINGS._serialized_start=6710
  _PRELOADEDUSERSETTINGS_PRIVACYSETTINGS._serialized_end=8108
  _PRELOADEDUSERSETTINGS_DEBUGSETTINGS._serialized_start=8110
  _PRELOADEDUSERSETTINGS_DEBUGSETTINGS._serialized_end=8227
  _PRELOADEDUSERSETTINGS_GAMELIBRARYSETTINGS._serialized_start=8230
  _PRELOADEDUSERSETTINGS_GAMELIBRARYSETTINGS._serialized_end=8531
  _PRELOADEDUSERSETTINGS_CUSTOMSTATUS._serialized_start=8533
  _PRELOADEDUSERSETTINGS_CUSTOMSTATUS._serialized_end=8622
  _PRELOADEDUSERSETTINGS_STATUSSETTINGS._serialized_start=8625
  _PRELOADEDUSERSETTINGS_STATUSSETTINGS._serialized_end=8922
  _PRELOADEDUSERSETTINGS_LOCALIZATIONSETTINGS._serialized_start=8925
  _PRELOADEDUSERSETTINGS_LOCALIZATIONSETTINGS._serialized_end=9088
  _PRELOADEDUSERSETTINGS_CLIENTTHEMESETTINGS._serialized_start=9091
  _PRELOADEDUSERSETTINGS_CLIENTTHEMESETTINGS._serialized_end=9395
  _PRELOADEDUSERSETTINGS_APPEARANCESETTINGS._serialized_start=9398
  _PRELOADEDUSERSETTINGS_APPEARANCESETTINGS._serialized_end=9736
  _PRELOADEDUSERSETTINGS_GUILDFOLDER._serialized_start=9739
  _PRELOADEDUSERSETTINGS_GUILDFOLDER._serialized_end=9942
  _PRELOADEDUSERSETTINGS_GUILDFOLDERS._serialized_start=9945
  _PRELOADEDUSERSETTINGS_GUILDFOLDERS._serialized_end=10091
  _PRELOADEDUSERSETTINGS_FAVORITECHANNEL._serialized_start=10094
  _PRELOADEDUSERSETTINGS_FAVORITECHANNEL._serialized_end=10278
  _PRELOADEDUSERSETTINGS_FAVORITES._serialized_start=10281
  _PRELOADEDUSERSETTINGS_FAVORITES._serialized_end=10597
  _PRELOADEDUSERSETTINGS_FAVORITES_FAVORITECHANNELSENTRY._serialized_start=10448
  _PRELOADEDUSERSETTINGS_FAVORITES_FAVORITECHANNELSENTRY._serialized_end=10597
  _PRELOADEDUSERSETTINGS_AUDIOCONTEXTSETTING._serialized_start=10599
  _PRELOADEDUSERSETTINGS_AUDIOCONTEXTSETTING._serialized_end=10672
  _PRELOADEDUSERSETTINGS_AUDIOSETTINGS._serialized_start=10675
  _PRELOADEDUSERSETTINGS_AUDIOSETTINGS._serialized_end=11216
  _PRELOADEDUSERSETTINGS_AUDIOSETTINGS_USERENTRY._serialized_start=10929
  _PRELOADEDUSERSETTINGS_AUDIOSETTINGS_USERENTRY._serialized_end=11070
  _PRELOADEDUSERSETTINGS_AUDIOSETTINGS_STREAMENTRY._serialized_start=11073
  _PRELOADEDUSERSETTINGS_AUDIOSETTINGS_STREAMENTRY._serialized_end=11216
  _PRELOADEDUSERSETTINGS_COMMUNITIESSETTINGS._serialized_start=11218
  _PRELOADEDUSERSETTINGS_COMMUNITIESSETTINGS._serialized_end=11329
  _PRELOADEDUSERSETTINGS_INBOXTAB._serialized_start=11331
  _PRELOADEDUSERSETTINGS_INBOXTAB._serialized_end=11409
  _PRELOADEDUSERSETTINGS_GUILDACTIVITYSTATUSRESTRICTIONDEFAULT._serialized_start=11411
  _PRELOADEDUSERSETTINGS_GUILDACTIVITYSTATUSRESTRICTIONDEFAULT._serialized_end=11484
  _PRELOADEDUSERSETTINGS_THEME._serialized_start=11486
  _PRELOADEDUSERSETTINGS_THEME._serialized_end=11525
  _PRELOADEDUSERSETTINGS_FAVORITECHANNELTYPE._serialized_start=11527
  _PRELOADEDUSERSETTINGS_FAVORITECHANNELTYPE._serialized_end=11619
# @@protoc_insertion_point(module_scope)
